<?php

namespace Litecms\Expenses\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Expenses\Interfaces\ExpensesRepositoryInterface;

class ExpensesPublicController extends BaseController
{
    // use ExpensesWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Expenses\Interfaces\ExpensesRepositoryInterface $expenses
     *
     * @return type
     */
    public function __construct(ExpensesRepositoryInterface $expenses)
    {
        $this->repository = $expenses;
        parent::__construct();
    }

    /**
     * Show expenses's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $expenses = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$expenses::$expenses.names'))
            ->view('$expenses::public.expenses.index')
            ->data(compact('$expenses'))
            ->output();
    }

    /**
     * Show expenses's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $expenses = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$expenses::$expenses.names'))
            ->view('$expenses::public.expenses.index')
            ->data(compact('$expenses'))
            ->output();
    }

    /**
     * Show expenses.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $expenses = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$expenses->name . trans('$expenses::$expenses.name'))
            ->view('$expenses::public.expenses.show')
            ->data(compact('$expenses'))
            ->output();
    }

}
