<?php

namespace Litecms\Expenses\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Expenses\Models\Expenses;

class ExpensesPolicy
{

    /**
     * Determine if the given user can view the expenses.
     *
     * @param UserPolicy $user
     * @param Expenses $expenses
     *
     * @return bool
     */
    public function view(UserPolicy $user, Expenses $expenses)
    {
        if ($user->canDo('expenses.expenses.view') && $user->isAdmin()) {
            return true;
        }

        return $expenses->user_id == user_id() && $expenses->user_type == user_type();
    }

    /**
     * Determine if the given user can create a expenses.
     *
     * @param UserPolicy $user
     * @param Expenses $expenses
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('expenses.expenses.create');
    }

    /**
     * Determine if the given user can update the given expenses.
     *
     * @param UserPolicy $user
     * @param Expenses $expenses
     *
     * @return bool
     */
    public function update(UserPolicy $user, Expenses $expenses)
    {
        if ($user->canDo('expenses.expenses.edit') && $user->isAdmin()) {
            return true;
        }

        return $expenses->user_id == user_id() && $expenses->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given expenses.
     *
     * @param UserPolicy $user
     * @param Expenses $expenses
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Expenses $expenses)
    {
        return $expenses->user_id == user_id() && $expenses->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given expenses.
     *
     * @param UserPolicy $user
     * @param Expenses $expenses
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Expenses $expenses)
    {
        if ($user->canDo('expenses.expenses.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given expenses.
     *
     * @param UserPolicy $user
     * @param Expenses $expenses
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Expenses $expenses)
    {
        if ($user->canDo('expenses.expenses.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
